/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.security.keystore;

import java.math.BigInteger;
import java.security.interfaces.RSAPublicKey;

/**
 * {@link RSAPublicKey} backed by Android Keystore.
 *
 * @hide
 */
public class AndroidKeyStoreRSAPublicKey extends AndroidKeyStorePublicKey implements RSAPublicKey {
    private final BigInteger mModulus;
    private final BigInteger mPublicExponent;

    public AndroidKeyStoreRSAPublicKey(String alias, int uid, byte[] x509EncodedForm, BigInteger modulus,
            BigInteger publicExponent) {
        super(alias, uid, KeyProperties.KEY_ALGORITHM_RSA, x509EncodedForm);
        mModulus = modulus;
        mPublicExponent = publicExponent;
    }

    public AndroidKeyStoreRSAPublicKey(String alias, int uid, RSAPublicKey info) {
        this(alias, uid, info.getEncoded(), info.getModulus(), info.getPublicExponent());
        if (!"X.509".equalsIgnoreCase(info.getFormat())) {
            throw new IllegalArgumentException(
                    "Unsupported key export format: " + info.getFormat());
        }
    }

    @Override
    public BigInteger getModulus() {
        return mModulus;
    }

    @Override
    public BigInteger getPublicExponent() {
        return mPublicExponent;
    }
}
